function [DF]=DF_delayed_vdP(x,lambda)

%%% input: x = (omega,a), where
%%%    - omega is the (complex) frequency of the periodic solution
%%%    - a is the vector of Fourier coefficients in C^(2m-1)
%%%    - lambda is the parameter

global tau eps

m=length(x)/2;

omega = x(1); %%% The frequency of the periodic orbit
a = x(2:end);

DF=zeros(2*m);

%%% D_{x}eta (First row) %%%
DF(1,m-2:m+4)=1; %%% Since F0 = sum_{|k|<=3} a_k

%%% D_{omega}g (Part of the first column) %%%
[a3]=cubic(a,a,a);
k=(-m+1:m-1)';
dmu_domega=-2*k.^2*omega-eps*1i*k-1i*k*tau.*exp(-1i*k*omega*tau);
DF(2:end,1)=dmu_domega.*a+1i*eps*k.*a3/3;

%%% D_{a}g (the rest) %%%

a2=quadratic(a);
mu=-k.^2*omega^2-eps*1i*k*omega-lambda+exp(-1i*k*omega*tau);

dg_da_non_linear = zeros(2*m-1);

for k=-m+1:m-1
    for ell=-m+1:m-1
        dg_da_non_linear(k+m,ell+m)=1i*eps*k*omega*a2(k-ell+2*m-1);
    end
end

DF(2:end,2:end)=diag(mu)+dg_da_non_linear;

end

function [s]=quadratic(a)

m=(length(a)+1)/2;
ta=[zeros(m,1);a;zeros(m,1)];
tu=ifft(ifftshift(ta));
F=fftshift(fft(tu.*tu));
s=(4*m-1)*F(2:4*m-2);

end
