function [tot_x,tot_lambda,tot_I,tot_delta,tot_norm] = validated_continuation_delayed_vdP(x0,lambda0,delta0,lambda_max)

% [tot_x,tot_lambda,tot_success,tot_I,delta0]=validated_continuation_delayed_vdP(x,lambda,lambda_max)
% As inputs, validated_continuation_delayed_vdP.m gets an approximate zero (x,lambda) of 
% the problem F^{(m)}(x,lambda)=0. validated_continuation_delayed_vdP.m will try to rigorously cover 
% the parameter range [lambda0,lambda_max] and validate the numerics.
%
% The outputs of validated_continuation_delayed_vdP.m are listed below. Suppose that we have n 
% continuation steps. For every i=1,...,n,
% (1) tot_x(:,i) is the numerical solution at the continuation step i
% (2) tot_lambda(i) is the value of the parameter lambda0 at the beginning of the continuation step i
% (3) tot_I(:,i) is the existence radius interval at the continuation step i 
% (4) tot_delta0(i) is the value of del_lambda0 at continuation step i

x=x0;
lambda=lambda0;
delta=delta0;

x=symmetrize_x(x);

tot_x(:,1)=x;
tot_lambda(1:2)=lambda;
tot_norm(1:2)=norm(x(2:end));
tot_success(1:2)=0;
tot_I=[-1;-1];
tot_delta(1:2)=delta;

nu=1;
k=1;

while (lambda<lambda_max)
    lambda=tot_lambda(k);
    x=tot_x(:,k);
    lambda=lambda+delta;
    dx=-DF_delayed_vdP(x,lambda)\dF_dlambda_delayed_vdP(x);
    x=x+delta*dx;
    [x]=Newton_F_delayed_vdP(x,lambda);
    x=symmetrize_x(x);
    tot_x(:,k+1)=x;
    tot_lambda(k+1)=lambda;
    tot_norm(k+1)=norm(x(2:end));
    lambda1=tot_lambda(k+1); lambda0=tot_lambda(k);
    x0=tot_x(:,k); x1=tot_x(:,k+1);
    [I,success]=radii_polynomials_delayed_vdP(x0,x1,lambda0,lambda1,nu);
    disp(['At lambda = ',num2str(lambda),', k = ',num2str(k),', delta = ',num2str(delta),',  success = ',num2str(success),', I = [',num2str(I(1)),',',num2str(I(2)),']'])
    tot_success(k)=success;
    tot_I(:,k)=I;
    tot_delta(k)=delta;
    if sum(I)==-2
        delta=9/10*delta;
    else
        k=k+1;
        if mod(k,10)==0
            delta=10/9*delta;
        end
    end
    
end